summaryrefslogtreecommitdiff
path: root/baseboard/dedede/baseboard.c
diff options
context:
space:
mode:
authorAseda Aboagye <aaboagye@google.com>2020-03-23 11:33:02 -0700
committerCommit Bot <commit-bot@chromium.org>2020-03-24 12:29:29 +0000
commit506fdc01b0f68ce972fa376c0b79bd1d578f0a0e (patch)
tree5ab9c3f4ebe91f0deeb848cc3928ad9b151af46a /baseboard/dedede/baseboard.c
parentf28e4caa00393a2bf16f37c929d7b5a95e654e90 (diff)
downloadchrome-ec-506fdc01b0f68ce972fa376c0b79bd1d578f0a0e.tar.gz
dedede: Check PG_VCCIO_EXT for ALL_SYS_PGOOD
According to the latest Intel documentation, ALL_SYS_PGOOD should also take into account PG_VCCIO_EXT. This commit does simply that. BUG=b:151783164 BRANCH=None TEST=Build and flash waddledoo, verify it still boots up. Signed-off-by: Aseda Aboagye <aaboagye@google.com> Change-Id: I1035f5d128d8fdece4b0c5b4642c3f7403db2170 Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2116667 Tested-by: Aseda Aboagye <aaboagye@chromium.org> Tested-by: George Engelbrecht <engeg@google.com> Auto-Submit: Aseda Aboagye <aaboagye@chromium.org> Reviewed-by: Jett Rink <jettrink@chromium.org> Commit-Queue: George Engelbrecht <engeg@google.com>
Diffstat (limited to 'baseboard/dedede/baseboard.c')
-rw-r--r--baseboard/dedede/baseboard.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/baseboard/dedede/baseboard.c b/baseboard/dedede/baseboard.c
index 9f6a37d3d1..26e2a81b1b 100644
--- a/baseboard/dedede/baseboard.c
+++ b/baseboard/dedede/baseboard.c
@@ -53,10 +53,12 @@ __override int intel_x86_get_pg_ec_dsw_pwrok(void)
__override int intel_x86_get_pg_ec_all_sys_pwrgd(void)
{
/*
* ALL_SYS_PWRGD is an AND of both DRAM PGOOD and VCCST PGOOD.
*/
return gpio_get_level(GPIO_PG_PP1050_ST_OD) &&
- gpio_get_level(GPIO_PG_DRAM_OD);
+ gpio_get_level(GPIO_PG_DRAM_OD) &&
+ gpio_get_level(GPIO_PG_VCCIO_EXT_OD);
}
__override void board_jsl_all_sys_pwrgd(int value)
@@ -53,10 +53,12 @@ __override int intel_x86_get_pg_ec_dsw_pwrok(void)
{
/*
- * ALL_SYS_PWRGD is an AND of both DRAM PGOOD and VCCST PGOOD.
+ * ALL_SYS_PWRGD is an AND of DRAM PGOOD, VCCST PGOOD, and VCCIO_EXT
+ * PGOOD.
*/
return gpio_get_level(GPIO_PG_PP1050_ST_OD) &&